Compatibility
=============

This documents compatibility support with existing systems such as
:mod:`logging` and :mod:`warnings`.

.. currentmodule:: logbook.compat

Logging Compatibility
---------------------

.. autofunction:: redirect_logging

.. autofunction:: redirected_logging

.. autoclass:: RedirectLoggingHandler
   :members:

.. autoclass:: LoggingHandler
   :members:


Warnings Compatibility
----------------------

.. autofunction:: redirect_warnings

.. autofunction:: redirected_warnings
